Aydin Denoising of OpenCell Images
==============================================================


.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vTb5DWYJSjzmzRyA9gy0Et80tz5AqhN_FW_P1UDMod2jZLwYtaRU7FKxO-RfPJ2hK7kl-weXBTH7GQR/pub?embedded=true" height="9380" width="720"></iframe>
